@@ -8,7 +8,7 @@ from typing import Any, Optional, Dict, Union
 
 import aiohttp.web
 import aiohttp.abc
-from dynamic_types.class_name import _prepare_class_name
+from dynamic_types.class_name import prepare_class_name
 from dynamic_types.create import create_type, create_dataclass
 from init_helpers import custom_dumps, is_instance, raise_if
 from init_helpers.dict_to_dataclass import dict_to_dataclass, convert_to_type
@@ -60,7 +60,7 @@ class BaseAnswer(abc.ABC):
         else:
             raise TypeError(f"Unexpected modifier type: {type(modifier)}")
 
-        new_type = create_type(_prepare_class_name([cls], modifier), [cls], field_name_to_value)
+        new_type = create_type(prepare_class_name([cls], modifier), [cls], field_name_to_value)
         return new_type
 
     @classmethod
@@ -202,7 +202,7 @@ class JsonableAnswer(Answer):
         if typing.get_origin(modifier) is not None or isinstance(modifier, type | UnionType):
             if cls.get_class_payload_type():
                 raise TypeError("Payload type already fixed")
-            return create_type(_prepare_class_name([cls], modifier), [cls], {_FIXED_PAYLOAD_TYPE__NAME: modifier})
+            return create_type(prepare_class_name([cls], modifier), [cls], {_FIXED_PAYLOAD_TYPE__NAME: modifier})
         return super().__class_getitem__(modifier)
 
 
@@ -215,14 +215,14 @@ class WrappedAnswer(JsonableAnswer):
     @classmethod
     def _wrap_type(cls, type_: type) -> type:
         attribute_key_to_type = {"done": bool, "result": type_} if type_ not in (None, type[None]) else {"done": bool}
-        return create_dataclass(_prepare_class_name([type_],  "Wrapped"), [cls], attribute_key_to_type)
+        return create_dataclass(prepare_class_name([type_],  "Wrapped"), [], attribute_key_to_type)
 
     def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, UnionType, type[None]]) -> type:
         if typing.get_origin(modifier) is not None or isinstance(modifier, type | UnionType):
             if cls.get_class_payload_type():
                 raise TypeError("Payload type already fixed")
             wrapped_type = cls._wrap_type(modifier)
-            return create_type(_prepare_class_name([cls], modifier), [cls], {_FIXED_PAYLOAD_TYPE__NAME: wrapped_type})
+            return create_type(prepare_class_name([cls], modifier), [cls], {_FIXED_PAYLOAD_TYPE__NAME: wrapped_type})
         return super().__class_getitem__(modifier)
 
     @staticmethod
@@ -255,7 +255,7 @@ class ErrorAnswer(JsonableAnswer):
         if isinstance(modifier, ErrorCode):
             if cls.get_class_error_code():
                 raise TypeError("ErrorCode already fixed")
-            return create_type(_prepare_class_name([cls], modifier), [cls], {_FIXED_ERROR_CODE__NAME: modifier})
+            return create_type(prepare_class_name([cls], modifier), [cls], {_FIXED_ERROR_CODE__NAME: modifier})
         return super().__class_getitem__(modifier)
 
     @classmethod
